# Chapter 3 Code for Ward & Gleditsch, Spatial Regression Models
# Sage, 2018.

# R version 3.4.3 (2017-11-30) -- "Kite-Eating Tree"
# Copyright (C) 2017 The R Foundation for Statistical Computing
# Platform: x86_64-apple-darwin15.6.0 (64-bit)

# Figure 3.1 Polity Scores as a Function of Logged GDP per Capita

rm(list = ls())
library(cshapes)
library(foreign)
library(ggplot2)
library(gridExtra)
library(grid)
p5<-read.csv("rawdata/p5.csv")
wmap <- cshp(date = as.Date("2015-01-01"),useGW=TRUE)  # get map from CSHAPES
wmap$ISO1AL3 <- as.character(wmap$ISO1AL3)
wmap$ISO1AL3[wmap$CNTRY_NAME == "Kosovo"] <- c("RKS")
wmap$ISO1AL3 <- as.factor(wmap$ISO1AL3)
wmap@data$id <- as.character(rownames(wmap@data))
wmap.df <- wmap@data
wmap.df$democ <- p5$democ[match(wmap.df$ISO1AL3, p5$scode)]
wmap.df$autoc <- p5$autoc[match(wmap.df$ISO1AL3, p5$scode)]

library(wbstats)
gdp <- wb(indicator = c("NY.GDP.PCAP.CD"),
          startdate = 2014, enddate = 2014,country="countries_only")
gdp$value <- log(gdp$value)

# join the GDP data to the map data.frame
# Table 3.1
wmap.df$gdp <- gdp$value[match(wmap.df$ISO1AL2, gdp$iso2c)]
# create polity score
wmap.df$polity<-wmap.df$democ - wmap.df$autoc


dat<-subset(wmap.df,select = c("polity","gdp"))
#ratio.display <- 4/3
#ratio.values <- (12.097-5.745)/(10- -10) + .1
# open png device
png(filename = "code-ch3/graphics/Fig3.1.png",
    width = 480, height = 480, units = "px", pointsize = 12,
    bg = "white")
ggplot(dat, aes(x=gdp, y=polity)) +
  geom_point(shape=16) +    
  geom_smooth(method=lm) + 
  labs(x = "GDP, logged per capita",y = "Polity Score") +
  coord_fixed(.2) +
  ggtitle("Figure 3.1") 
dev.off()