# Chapter 3 Code for Ward & Gleditsch, Spatial Regression Models
# Sage, 2018.

# R version 3.4.3 (2017-11-30) -- "Kite-Eating Tree"
# Copyright (C) 2017 The R Foundation for Statistical Computing
# Platform: x86_64-apple-darwin15.6.0 (64-bit)

# Figure 3.2
rm(list = ls())

library(cshapes)
library(foreign)
library(ggplot2)
library(gridExtra)
library(grid)
library(EnvStats)

p5<-read.csv("rawdata/p5.csv")
wmap <- cshp(date = as.Date("2015-01-01"),useGW=TRUE)  # get map from CSHAPES
wmap$ISO1AL3 <- as.character(wmap$ISO1AL3)
wmap$ISO1AL3[wmap$CNTRY_NAME == "Kosovo"] <- c("RKS")
wmap$ISO1AL3 <- as.factor(wmap$ISO1AL3)
wmap@data$id <- as.character(rownames(wmap@data))
wmap.df <- wmap@data
wmap.df$democ <- p5$democ[match(wmap.df$ISO1AL3, p5$scode)]
wmap.df$autoc <- p5$autoc[match(wmap.df$ISO1AL3, p5$scode)]

library(wbstats)
gdp <- wb(indicator = c("NY.GDP.PCAP.CD"),
          startdate = 2014, enddate = 2014,country="countries_only")
gdp$value <- log(gdp$value)

# join the GDP data to the map data.frame
# Table 3.1
wmap.df$gdp <- gdp$value[match(wmap.df$ISO1AL2, gdp$iso2c)]
# create polity score
wmap.df$polity<-wmap.df$democ - wmap.df$autoc

dat<-subset(wmap.df,select = c("polity","gdp"))
ols.1.2<-glm(polity ~gdp,data=dat)

# Figure 3.2
png(filename = "code-ch3/graphics/Fig3.2.png",
    width = 480, height = 480, units = "px", pointsize = 12,
    bg = "white")
qqnorm(resid(ols.1.2),pch=19,las = 1,cex=.7,plot.type="Q-Q",points.col="black",
       ylab="Sample Quantiles",xlab="Theoretical Quantiles",
       main="Figure 3.2")
segments(-2.9, -15, x1 = 1, y1 = 8,
         col = par("fg"), lty = par("lty"), lwd = par("lwd"))
dev.off()

# Figure 3.3
png(filename = "code-ch3/graphics/Fig3.3.png",
    width = 480, height = 480, units = "px", pointsize = 12,
    bg = "white")
plot(density(residuals(ols.1.2)),ylim=c(0,.5),
     xlim=c(-20,10),bty="n",axes=F,xlab="",ylab="",
     lwd=3,main="Figure 3.3")
lines(density(rnorm(100000,0,1)),lwd=3,col="gray")
axis(side=1,at=c(-20,-10,0,10))
dev.off()