# Chapter 3 Code for Ward & Gleditsch, Spatial Regression Models
# Sage, 2018.

# R version 3.4.3 (2017-11-30) -- "Kite-Eating Tree"
# Copyright (C) 2017 The R Foundation for Statistical Computing
# Platform: x86_64-apple-darwin15.6.0 (64-bit)

# Figure 3.5  Simple Network Visualizaiton of Linkages among 195 Countries

rm(list = ls())

library(GGally)
library(network)
library(sna)
library('igraph')
library(cshapes)
library(foreign)
library(ggplot2)

p5<-read.csv("rawdata/p5.csv")
wmap <- cshp(date = as.Date("2015-01-01"),useGW=TRUE)  # get map from CSHAPES
wmap$ISO1AL3 <- as.character(wmap$ISO1AL3)
wmap$ISO1AL3[wmap$CNTRY_NAME == "Kosovo"] <- c("RKS")
wmap$ISO1AL3 <- as.factor(wmap$ISO1AL3)
wmap@data$id <- as.character(rownames(wmap@data))
wmap.df <- wmap@data
wmap.df$democ <- p5$democ[match(wmap.df$ISO1AL3, p5$scode)]
wmap.df$autoc <- p5$autoc[match(wmap.df$ISO1AL3, p5$scode)]

library(wbstats)
gdp <- wb(indicator = c("NY.GDP.PCAP.CD"),
          startdate = 2014, enddate = 2014,country="countries_only")
gdp$value <- log(gdp$value)

# join the GDP data to the map data.frame
wmap.df$gdp <- gdp$value[match(wmap.df$ISO1AL2, gdp$iso2c)]
# create polity score
wmap.df$polity<-wmap.df$democ - wmap.df$autoc

wmat.195 <- distmatrix(as.Date("2015-1-1"), type="mindist", tolerance=0.5, useGW=TRUE)
wmat.195[wmat.195<=200]<-1
wmat.195[wmat.195>200]<-0
diag(wmat.195)<-0
wmap.df.sorted<-wmap.df[order(wmap.df$GWCODE),] 
colnames(wmat.195)<-row.names(wmat.195)<-wmap.df.sorted$ISO1AL3

net195<-network(wmat.195)
net.igraph <- graph_from_adjacency_matrix(wmat.195, 
                 mode = c("undirected"),  diag = FALSE)
sizes<-wmap.df$gdp
sizes[is.na(sizes)]<-5.75

V(net.igraph)$gdp=sizes*1.5
V(net.igraph)$size <- degree(net.igraph) ##V(net.igraph)$gdp
iso <- V(net.igraph)[degree(net.igraph)==0]
g2 <- delete.vertices(net.igraph, iso)
png(filename = "code-ch3/graphics/Fig3.5.png",
    width = 480, height = 480, units = "px", pointsize = 12,
    bg = "white")
plot(g2,vertex.label.cex=.6,
     vertex.color = "skyblue")
dev.off()
