# Chapter 3 Code for Ward & Gleditsch, Spatial Regression Models
# Sage, 2018.

# R version 3.4.3 (2017-11-30) -- "Kite-Eating Tree"
# Copyright (C) 2017 The R Foundation for Statistical Computing
# Platform: x86_64-apple-darwin15.6.0 (64-bit)

# Figure 3.6 Map of Centroids
library(RColorBrewer)
library(maptools)
library(spdep)
library(sp)
library(rgdal)

# Read a Robinson projection map from an ESRI shapefile
newprojection <- "+proj=robin +lon_0=0 +x_0=0 +y_0=0"
#rob.shp <- readOGR(dsn="shapefiles/110m_cultural", layer="ne_110m_admin_0_countries")

rob.shp <- readShapeSpatial("shapefiles/world2002/wg2002worldmap.shp",proj4string =
                              CRS(newprojection),
                            IDvar = "FIPS_CNTRY",repair=TRUE,force_ring=TRUE, verbose=TRUE)

# Add coordinates
coords <- coordinates(rob.shp)

# Replot the map itself without a bounding box
png(filename = "code-ch3/graphics/Fig3.6.png",
    width = 480, height = 480, units = "px", pointsize = 12,
    bg = "white")
plot(rob.shp, border="Grey",
     xaxt="n", yaxt="n", bty="n",
     lwd=.75, las=1, ylab="",
     main="Centroids and Capitals", xlab="")

# Add the centroids
points(coordinates(rob.shp), pch=19,cex=.25, col="red")

# Latitude and Longitude
ll.mat <- cbind(as.numeric(as.character(rob.shp$Long)),
                as.numeric(as.character(rob.shp$Lat)))
row.names(ll.mat) <- 1:nrow(ll.mat)
llCRS <- CRS("+proj=longlat +ellps+WGS84")
longlat <-  SpatialPoints(ll.mat,proj4string = llCRS)

longlat.transf <- spTransform(longlat,
                              CRS("+proj=robin +ellps+WGS84+lon_0=0 + x_0=0 +y_0=0"))
points(coordinates(longlat.transf),pch=19,cex=.25,col="black")

# Add segments between centroids and capitals
# but delete Kiribati, as it crosses date line
diffs <- cbind(coordinates(rob.shp),coordinates(longlat.transf))
segments(diffs[-91,1],diffs[-91,2],diffs[-91,3],diffs[-91,4],col="slategray4")
dev.off()
