# Chapter 3 Code for Ward & Gleditsch, Spatial Regression Models
# Sage, 2018.

# R version 3.4.3 (2017-11-30) -- "Kite-Eating Tree"
# Copyright (C) 2017 The R Foundation for Statistical Computing
# Platform: x86_64-apple-darwin15.6.0 (64-bit)

setwd("/Users/mdw/Dropbox/research/Books/SRMV2/SRMRepository")
# Figure 3.7 Anselin-Moran Plot
rm(list = ls())

library(cshapes)
library(foreign)
library(ggplot2)
library(gridExtra)
p5<-read.csv("rawdata/p5.csv")

wmap <- cshp(date = as.Date("2015-01-01"),useGW=TRUE)  # get map from CSHAPES
wmap$ISO1AL3 <- as.character(wmap$ISO1AL3)
wmap$ISO1AL3[wmap$CNTRY_NAME == "Kosovo"] <- c("RKS")
wmap$ISO1AL3 <- as.factor(wmap$ISO1AL3)
wmap@data$id <- as.character(rownames(wmap@data))
wmap.df <- wmap@data
wmap.df$democ <- p5$democ[match(wmap.df$ISO1AL3, p5$scode)]
wmap.df$autoc <- p5$autoc[match(wmap.df$ISO1AL3, p5$scode)]

library(wbstats)
gdp <- wb(indicator = c("NY.GDP.PCAP.CD"),
          startdate = 2014, enddate = 2014,country="countries_only")
gdp$value <- log(gdp$value)

# join the GDP data to the map data.frame
# Table 3.1
wmap.df$gdp <- gdp$value[match(wmap.df$ISO1AL2, gdp$iso2c)]
# create polity score
wmap.df$polity<-wmap.df$democ - wmap.df$autoc

# Prune Data Set
moran.df<-subset(wmap.df,select = c("GWCODE","polity","gdp"))
pruned<-na.omit(moran.df)
pruned<-pruned[with(pruned, order(GWCODE)), ]
row.names(pruned)<-pruned$GWCODE
ols.1.2<-glm(polity ~ gdp,data=pruned)
#summary(ols.1.2)
#library(xtable)
#xtable(ols.1.2)

# Now some statistical processing
# wdist has the distance scores, in order of GW codes
wmap.dist <- distmatrix(date = as.Date("2015-01-01"),type="mindist") 

index<-as.character(pruned$GWCODE)
w.dist<-wmap.dist[index,index]
# recode distance data to be binary, for distance < 550km
w.dist[w.dist<=400]<-1
w.dist[w.dist>=400]<-0
w.dist.rowstd<-w.dist/rowSums(w.dist)

# create spatial lag of residuals
resid.splag<- w.dist.rowstd%*%resid(ols.1.2)
resid.splag.std<-scale(resid.splag)
resid.std<-scale(resid(ols.1.2))
png(filename = "code-ch3/graphics/Fig3.7.png",
    width = 480, height = 480, units = "px", pointsize = 12,
    bg = "white")
plot(resid.std,resid.splag.std,las=1,pch=19,xlim=c(-3,3),
     ylim=c(-3,3),ylab="Standardized Spatial Lag of OLS Residuals",
     xlab="Standardized OLS Residuals",main="")
polygon(c(0,0,1,1),c(0,1,1,0),col=rgb(	135/255,206/255,250/255,0.5))
polygon(c(-1,-1,0,0),c(-1,0,0,-1),col=rgb(	135/255,206/255,250/255,0.5))
points(resid.std,resid.splag.std,pch=19)

segments(-2, -2, -2, 2,lwd=2)
segments(2, -2, 2, 2,lwd=2)
segments(-2, 2, 2,2,lwd=2)
segments(-2, -2, 2,-2,lwd=2)
segments(-1, -1, -1, 1,lwd=2)
segments(1, -1, 1, 1,lwd=2)
segments(-1, 1, 1,1,lwd=2)
segments(-1, -1, 1,-1,lwd=2)
segments(-2, 0, 2,0,lwd=2)
segments(0, -2,0,2,lwd=2)

rug(resid.std, ticksize = 0.03, side = 1, lwd = 0.5)
rug(resid.splag.std, ticksize = 0.03, side = 2, lwd = 0.5)

abline(lm(resid.splag.std~-1+resid.std),lwd=2)
dev.off()

coef(lm(resid.splag.std~-1+resid.std))

moran.test(resid.std,mat2listw(w.dist.rowstd))