# Chapter 3 Code for Ward & Gleditsch, Spatial Regression Models
# Sage, 2018.

# R version 3.4.3 (2017-11-30) -- "Kite-Eating Tree"
# Copyright (C) 2017 The R Foundation for Statistical Computing
# Platform: x86_64-apple-darwin15.6.0 (64-bit)

# Figure 3.8 Choropleth of Local Indicators of Spatial Autocorrelation of Polity Score, i.e.,
# the localized Moran’s I. Spatial weights dichotomized at 400 kilometers.

library(RColorBrewer)
library(cshapes) 
library(wbstats)
rm(list = ls())
p5<-read.csv("rawdata/p5.csv")
wmap <- cshp(date = as.Date("2015-01-01"),useGW=TRUE)  # get map from CSHAPES
wmap$ISO1AL3 <- as.character(wmap$ISO1AL3)
wmap$ISO1AL3[wmap$CNTRY_NAME == "Kosovo"] <- c("RKS")
wmap$ISO1AL3 <- as.factor(wmap$ISO1AL3)
wmap@data$id <- as.character(rownames(wmap@data))
wmap.df <- wmap@data
wmap@data$democ <- p5$democ[match(wmap@data$ISO1AL3, p5$scode)]
wmap@data$autoc <- p5$autoc[match(wmap@data$ISO1AL3, p5$scode)]
wmap@data$polity <- wmap@data$democ - wmap@data$autoc
# for convenience assign 0 to NA
wmap@data$polity[is.na(wmap@data$polity)]<- 0
pol <- wmap@data$polity
library(classInt)

nclr <- 6
plotclr <- brewer.pal(nclr,"Spectral")
class = classIntervals(pol, n = 6, 
                       style = "fixed", fixedBreaks = c(-10, -6, -3, 0, 3, 6, 10))
colcode <- findColours(class, plotclr)
plot(wmap, col=colcode)
legend(-170,0, legend=names(attr(colcode, "table")),
       fill=attr(colcode, "palette"), cex=0.6, bty="n")

# now get distance matrix
wmap.dist <- distmatrix(date = as.Date("2015-01-01")) 

# recode distance data to be binary, for distance < 400km
w.dist<-wmap.dist
w.dist[w.dist<=400]<-1
w.dist[w.dist>400]<-0
# row standardize
w.dist.rstd<-w.dist/rowSums(w.dist)
# 0 on diagonal
diag(w.dist.rstd)<-0
which(rowSums(w.dist.rstd)==0)
w.dist.rstd <- w.dist.rstd[as.character(wmap@data$GWCODE),as.character(wmap@data$GWCODE)]

# create spatial lag of polity. round result
wmap@data$sp.lag.polity<- round((w.dist.rstd)%*%(wmap@data$polity))
library(localmoran)
lmoran <- localmoran(as.vector(wmap@data$sp.lag.polity), mat2listw(w.dist.rstd))
wmap@data$LISA<-lmoran[,1]

pol <- wmap@data$LISA
library(classInt)

nclr <- 6
plotclr <- brewer.pal(nclr,"PRGn")
class = classIntervals(pol, n = 6, 
                       style = "fixed", fixedBreaks = c(-1.4,0.0, 0.18,0.549,0.85,3.72  ))
colcode <- findColours(class, plotclr)
png(filename = "code-ch3/graphics/Fig3.8.png",
    width = 480, height = 480, units = "px", pointsize = 12,
    bg = "white")
plot(wmap, col=colcode)
legend(-170,0, legend=names(attr(colcode, "table")),
       fill=attr(colcode, "palette"), cex=0.6, bty="n")
dev.off()
