# Chapter 3 Code for Ward & Gleditsch, Spatial Regression Models
# Sage, 2018.

# R version 3.4.3 (2017-11-30) -- "Kite-Eating Tree"
# Copyright (C) 2017 The R Foundation for Statistical Computing
# Platform: x86_64-apple-darwin15.6.0 (64-bit)

# Table 3.2

rm(list = ls())

library(cshapes)
library(foreign)
library(ggplot2)
library(gridExtra)
library(grid)
library(EnvStats)
library(xtable)

p5<-read.csv("rawdata/p5.csv")
wmap <- cshp(date = as.Date("2015-01-01"),useGW=TRUE)  # get map from CSHAPES
wmap$ISO1AL3 <- as.character(wmap$ISO1AL3)
wmap$ISO1AL3[wmap$CNTRY_NAME == "Kosovo"] <- c("RKS")
wmap$ISO1AL3 <- as.factor(wmap$ISO1AL3)
wmap@data$id <- as.character(rownames(wmap@data))
wmap.df <- wmap@data
wmap.df$democ <- p5$democ[match(wmap.df$ISO1AL3, p5$scode)]
wmap.df$autoc <- p5$autoc[match(wmap.df$ISO1AL3, p5$scode)]

library(wbstats)
gdp <- wb(indicator = c("NY.GDP.PCAP.CD"),
          startdate = 2014, enddate = 2014,country="countries_only")
gdp$value <- log(gdp$value)

# join the GDP data to the map data.frame
# Table 3.1
wmap.df$gdp <- gdp$value[match(wmap.df$ISO1AL2, gdp$iso2c)]
# create polity score
wmap.df$polity<-wmap.df$democ - wmap.df$autoc

dat<-subset(wmap.df,select = c("polity","gdp"))
ols.1.2<-glm(polity ~gdp,data=dat)
xtable(ols.1.2,digits=2,caption="OLS Regression of Polity on Logged GDP per capita.")