# Chapter 3 Code for Ward & Gleditsch, Spatial Regression Models
# Sage, 2018.

# R version 3.4.3 (2017-11-30) -- "Kite-Eating Tree"
# Copyright (C) 2017 The R Foundation for Statistical Computing
# Platform: x86_64-apple-darwin15.6.0 (64-bit)

# Table 3.6

rm(list = ls())

library(cshapes)
library(foreign)
library(ggplot2)
library(gridExtra)
p5<-read.csv("rawdata/p5.csv")
wmap <- cshp(date = as.Date("2015-01-01"),useGW=TRUE)  # get map from CSHAPES
wmap$ISO1AL3 <- as.character(wmap$ISO1AL3)
wmap$ISO1AL3[wmap$CNTRY_NAME == "Kosovo"] <- c("RKS")
wmap$ISO1AL3 <- as.factor(wmap$ISO1AL3)
wmap@data$id <- as.character(rownames(wmap@data))
wmap.df <- wmap@data
wmap.df$democ <- p5$democ[match(wmap.df$ISO1AL3, p5$scode)]
wmap.df$autoc <- p5$autoc[match(wmap.df$ISO1AL3, p5$scode)]
wmap.df$polity<-wmap.df$democ - wmap.df$autoc


# Prune Data Set
temp<-subset(wmap.df,select = c("GWCODE","ISONAME","polity"))
pruned<-na.omit(temp)
pruned<-pruned[with(pruned, order(GWCODE)), ]
row.names(pruned)<-pruned$GWCODE

# wdist has the distance scores, in order of GW codes
wmap.dist <- distmatrix(date = as.Date("2015-01-01"),type="mindist") 

index<-as.character(pruned$GWCODE)
w.dist<-wmap.dist[index,index]
# recode distance data to be binary, for distance < 550km
w.dist[w.dist<=400]<-1
w.dist[w.dist>=400]<-0
w.dist.rowstd<-w.dist/rowSums(w.dist)

# create spatial lag of residuals
pruned$polity.splag<- round(w.dist.rowstd%*%pruned$polity,2)

# Prune Data Set
tab.df<-subset(pruned,select = c("GWCODE","ISONAME","polity","polity.splag"))
pruned<-pruned[with(pruned, order(GWCODE)), ]
row.names(pruned)<-pruned$GWCODE

#  now calculate the spatial lags, and add back to pruned.

sorted<-pruned[order(pruned$polity.splag),]
bottom<-head(sorted,10)
bottom<-bottom[,c(2:4)]
levels(bottom$ISONAME)[98] <- 'Laos'
bottom[order(bottom$polity.splag,decreasing =TRUE),]

top<-tail(sorted,10)
top<-top[,c(2:4)]
top[order(bottom$polity.splag,decreasing =TRUE),]

rbind(top,bottom)

xtable(rbind(top,bottom),caption="Democracy data (PITF: 2015). Top and bottom 10 countries in
terms of spatially lagged Polity scores.")
