# Chapter 3 Code for Ward & Gleditsch, Spatial Regression Models
# Sage, 2018.

# R version 3.4.3 (2017-11-30) -- "Kite-Eating Tree"
# Copyright (C) 2017 The R Foundation for Statistical Computing
# Platform: x86_64-apple-darwin15.6.0 (64-bit)

rm(list = ls())

# Figure 3.1 Polity Scores as a Function of Logged GDP per Capita
library(cshapes)
library(foreign)
library(ggplot2)
library(gridExtra)
library(grid)
p5<-read.csv("rawdata/p5.csv")
wmap <- cshp(date = as.Date("2015-01-01"),useGW=TRUE)  # get map from CSHAPES
wmap$ISO1AL3 <- as.character(wmap$ISO1AL3)
wmap$ISO1AL3[wmap$CNTRY_NAME == "Kosovo"] <- c("RKS")
wmap$ISO1AL3 <- as.factor(wmap$ISO1AL3)
wmap@data$id <- as.character(rownames(wmap@data))
wmap.df <- wmap@data
wmap.df$democ <- p5$democ[match(wmap.df$ISO1AL3, p5$scode)]
wmap.df$autoc <- p5$autoc[match(wmap.df$ISO1AL3, p5$scode)]

library(wbstats)
gdp <- wb(indicator = c("NY.GDP.PCAP.CD"),
          startdate = 2014, enddate = 2014,country="countries_only")
gdp$value <- log(gdp$value)

# join the GDP data to the map data.frame
# Table 3.1
wmap.df$gdp <- gdp$value[match(wmap.df$ISO1AL2, gdp$iso2c)]
# create polity score
wmap.df$polity<-wmap.df$democ - wmap.df$autoc

# Table 3.1, top 10 and bottom 10

# Table 3.2, OLS output
# now simple regression Table 1.2 Ward & Gleditsch
ols.1.2<-glm(wmap.df$polity ~(wmap.df$gdp))
summary(ols.1.2)
library(xtable)
xtable(ols.1.2)

# Figure 3.1
dat<-subset(wmap.df,select = c("polity","gdp"))
#ratio.display <- 4/3
#ratio.values <- (12.097-5.745)/(10- -10) + .1
ggplot(dat, aes(x=gdp, y=polity)) +
  geom_point(shape=16) +    
  geom_smooth(method=lm) + 
  labs(x = "GDP, logged per capita",y = "Polity Score") +
  coord_fixed(.2) +
  ggtitle("Figure 3.1") 

# Figure 3.2
qqPlot(residuals(ols.1.2),pch=19,las = 1,cex=.7,
       ylab="Sample Quantiles",xlab="Theoretical Quantiles",
       col.lines="black",grid=FALSE, main="Figure 3.2")

# This is Figure 3.3 
plot(density(residuals(ols.1.2)),ylim=c(0,.5),
     xlim=c(-20,10),bty="n",axes=F,xlab="",ylab="",
     lwd=3,main="Figure 3.3")
lines(density(rnorm(100000,0,1)),lwd=3,col="gray")
axis(side=1,at=c(-20,-10,0,10))


# Table 3.3 is not replicated.
# Table 3.4 is not replicated


# Figure 3.4 Network Visualization among eight European countries
cshp.data <- cshp()
easyeight.shp <- cshp.data[cshp.data$COWCODE%in% c(200,220,260,325,375,380,385,390),]
wmat.195 <- distmatrix(as.Date("2015-1-1"), type="mindist", tolerance=0.5, useGW=TRUE)
ee<-as.character(c(200,220,260,325,375,380,385,390))
wmat.8 <- wmat.195[ee,ee]
w8.dist<-wmat.8
w8.dist[w8.dist<=200]<-1
w8.dist[w8.dist>200]<-0
col.names(w8.dist)<-row.names(w8.dist)<-c("UK","FRN","ITA","GER","DEN","SWE","NOR","FIN")
diag(w8.dist)<-0
net<-network(w8.dist)

library(GGally)
library(network)
library(sna)
library(ggplot2)
# vertex names
set.seed(12345)
network.vertex.names(net) = c("UK","FRN","ITA","GER","DEN","SWE","NOR","FIN")
ggnet2(net, node.size = 14, node.color = "gray30", edge.size = 1, edge.color = "grey",
       mode = "kamadakawai",label = TRUE,color = "black", label.color = "white")

# Figure 3.5  Simple Network Visualizaiton of Linkages among 195 Countries
rm(list = ls())

library(cshapes)
library(foreign)
library(ggplot2)
library(gridExtra)
library(grid)
p5<-read.csv("rawdata/p5.csv")
wmap <- cshp(date = as.Date("2015-01-01"),useGW=TRUE)  # get map from CSHAPES
wmap$ISO1AL3 <- as.character(wmap$ISO1AL3)
wmap$ISO1AL3[wmap$CNTRY_NAME == "Kosovo"] <- c("RKS")
wmap$ISO1AL3 <- as.factor(wmap$ISO1AL3)
wmap@data$id <- as.character(rownames(wmap@data))
wmap.df <- wmap@data
wmap.df$democ <- p5$democ[match(wmap.df$ISO1AL3, p5$scode)]
wmap.df$autoc <- p5$autoc[match(wmap.df$ISO1AL3, p5$scode)]

library(wbstats)
gdp <- wb(indicator = c("NY.GDP.PCAP.CD"),
          startdate = 2014, enddate = 2014,country="countries_only")
gdp$value <- log(gdp$value)

# join the GDP data to the map data.frame
wmap.df$gdp <- gdp$value[match(wmap.df$ISO1AL2, gdp$iso2c)]
# create polity score
wmap.df$polity<-wmap.df$democ - wmap.df$autoc

wmat.195 <- distmatrix(as.Date("2015-1-1"), type="mindist", tolerance=0.5, useGW=TRUE)
wmat.195[wmat.195<=200]<-1
wmat.195[wmat.195>200]<-0
diag(wmat.195)<-0
wmap.df.sorted<-wmap.df[order(wmap.df$GWCODE),] 
colnames(wmat.195)<-row.names(wmat.195)<-wmap.df.sorted$ISO1AL3

library(GGally)
library(network)
library(sna)
library(ggplot2)
library('igraph')

net195<-network(wmat.195)
net.igraph <- graph_from_adjacency_matrix(wmat.195, 
                                          mode = c("undirected"),  diag = FALSE)
sizes<-wmap.df$gdp
sizes[is.na(sizes)]<-5.75

V(net.igraph)$gdp=sizes*1.5
V(net.igraph)$size <- degree(net.igraph) ##V(net.igraph)$gdp
plot(net.igraph,vertex.label.cex=.6,
     vertex.color = "skyblue")

# Table 3.5 is not replicated

# Table 3.6 Top and Bottom 10 Spatial Lag Polity Scores


# Figure 3.6 Map of Centroids

# Figure 3.7 Anselin-Moran Plot of OLS Residuals 

# Figure 3.8 Choropleth of LISA 

# Now some statistical processing
# wdist has the distance scores, in order of GW codes
wmap.dist <- distmatrix(date = as.Date("2015-01-01")) 

raw.df<-wmap@data
raw.df<-raw.df[with(raw.df, order(GWCODE)), ]
raw.df$gdp <- gdp$value[match(raw.df$ISO1AL2, gdp$iso2c)]
raw.df$democ <- p5$democ[match(raw.df$ISO1AL3, p5$scode)]
raw.df$autoc <- p5$autoc[match(raw.df$ISO1AL3, p5$scode)]
raw.df$polity<-raw.df$democ - raw.df$autoc
# recode distance data to be binary, for distance < 550km
w.dist<-wmap.dist
w.dist[w.dist<=2000]<-1
w.dist[w.dist>2000]<-0
rowSums(w.dist)
summary(as.vector(w.dist))
plot(density(as.vector(w.dist)),lwd=6)
table(as.vector(w.dist))

# create spatial lag of polity
# set NA to 0 for dep var
set.seed(123)
raw.df$polity[is.na(raw.df$polity)]<- 
  round(runif(1,-10,10),0)
raw.df$sp.lag.polity<- (w.dist)%*%(raw.df$polity)
raw.df$sp.lag.polity.std<-scale(raw.df$sp.lag.polity) 
raw.df$polity.std<-scale(raw.df$polity)
plot(raw.df$polity.std,raw.df$sp.lag.polity.std,
     pch=19,bty="n",ylim=c(-3,3),xlim=c(-3,3))
lines( c(-2,-2,+2,+2,-2), c(-2,+2,+2,-2,-2) )
lines( c(-1,-1,+1,+1,-1), c(-1,+1,+1,-1,-1) )
lines( c(-2,+2), c(0,0) )
lines( c(0,0), c(-2,+2) )


### something new

listw.obj<-mat2listw(w.dist)
# ASSIGN A VALUE FOR NA
raw.df$gdp[is.na(raw.df$gdp)]<-4.0
wed.1.fit <- glm(polity ~ (gdp), data=raw.df)
summary(wed.1.fit)
library(xtable)
xtable(summary(wed.1.fit))

moran.test(resid(wed.1.fit),listw.obj)

plot(raw.df$gdp,raw.df$polity,bty="n",pch=19,cex=2.25)
plot(density(resid(wed.1.fit)),bty="n",lwd=4,main="Residual Density",xlab="Residuals")
abline(v=-10,col="red",lwd=5)


